@@ -18,7 +18,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #                                                                               #
 # This script will compile and run the c examples from source files installed   #
-# in .../share/hdf5_examples/c using h5cc or h5pc.  The order for running       #
+# in .../share/examples/hdf5/c using h5cc or h5pc.  The order for running       #
 # programs with RunTest in the MAIN section below is taken from the Makefile.   #
 # The order is important since some of the test programs use data files created #
 # by earlier test programs.  Any future additions should be placed accordingly. #
@@ -31,7 +31,7 @@ EXIT_FAILURE=1
  
 # Where the tool is installed.
 # default is relative path to installed location of the tools 
-prefix="${prefix:-../../../}"
+prefix="${prefix:-../../..}"
 PARALLEL=no             # Am I in parallel mode?
 AR="ar"
 RANLIB="ranlib"
@@ -123,7 +123,23 @@ then
         RunTest h5_elink_unix2win &&\
         rm h5_elink_unix2win &&\
         RunTest h5_shared_mesg &&\
-        rm h5_shared_mesg); then
+        rm h5_shared_mesg &&\
+        RunTest h5_vds-eiger &&\
+        rm h5_vds-eiger &&\
+        RunTest h5_vds-exclim &&\
+        rm h5_vds-exclim &&\
+        RunTest h5_vds-exc &&\
+        rm h5_vds-exc &&\
+        RunTest h5_vds-simpleIO &&\
+        rm h5_vds-simpleIO &&\
+        RunTest h5_vds-percival &&\
+        rm h5_vds-percival &&\
+        RunTest h5_vds-percival-unlim &&\
+        rm h5_vds-percival-unlim &&\
+        RunTest h5_vds-percival-unlim-maxmin&&\
+        rm h5_vds-percival-unlim-maxmin &&\
+        RunTest h5_vds &&\
+        rm h5_vds); then
         EXIT_VALUE=${EXIT_SUCCESS}
     else
         EXIT_VALUE=${EXIT_FAILURE}
